@@ -1,8 +1,10 @@
-package Dist::Zilla::Plugin::GitHub; # git description: v0.40-16-g8b40cd7
-our $VERSION = '0.41';
+package Dist::Zilla::Plugin::GitHub; # git description: v0.41-8-gb14f403
+# ABSTRACT: Plugins to integrate Dist::Zilla with GitHub
 use strict;
 use warnings;
 
+our $VERSION = '0.42';
+
 use JSON::MaybeXS;
 use Moose;
 use Try::Tiny;
@@ -33,10 +35,6 @@ has prompt_2fa => (
     default => 0
 );
 
-#pod =head1 NAME
-#pod
-#pod Dist::Zilla::Plugin::GitHub - Plugins to integrate Dist::Zilla with GitHub
-#pod
 #pod =head1 DESCRIPTION
 #pod
 #pod B<Dist::Zilla::Plugin::GitHub> is a set of plugins for L<Dist::Zilla> intended
@@ -124,8 +122,12 @@ sub _get_repo_name {
 
     $repo = $self->repo if $self->repo;
 
-    my ($url) = map /Fetch URL: (.*)/,
-        $git->remote('show', '-n', $self->remote);
+    my $url;
+    {
+        local $ENV{LANG}='C';
+        ($url) = map /Fetch URL: (.*)/,
+            $git->remote('show', '-n', $self->remote);
+    }
 
     $url =~ /github\.com.*?[:\/](.*)\.git$/;
     $repo = $1 unless $repo and not $1;
@@ -170,22 +172,6 @@ sub _check_response {
     }
 }
 
-#pod =head1 AUTHOR
-#pod
-#pod Alessandro Ghedini <alexbio@cpan.org>
-#pod
-#pod =head1 LICENSE AND COPYRIGHT
-#pod
-#pod Copyright 2011 Alessandro Ghedini.
-#pod
-#pod This program is free software; you can redistribute it and/or modify it
-#pod under the terms of either: the GNU General Public License as published
-#pod by the Free Software Foundation; or the Artistic License.
-#pod
-#pod See http://dev.perl.org/licenses/ for more information.
-#pod
-#pod =cut
-
 1; # End of Dist::Zilla::Plugin::GitHub
 
 __END__
@@ -196,11 +182,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::GitHub
+Dist::Zilla::Plugin::GitHub - Plugins to integrate Dist::Zilla with GitHub
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 DESCRIPTION
 
@@ -223,23 +209,10 @@ This distribution also provides an additional C<dzil> command (L<dzil
 gh|Dist::Zilla::App::Command::gh>) and a L<plugin
 bundle|Dist::Zilla::PluginBundle::GitHub>.
 
-=head1 NAME
+=head1 SUPPORT
 
-Dist::Zilla::Plugin::GitHub - Plugins to integrate Dist::Zilla with GitHub
-
-=head1 AUTHOR
-
-Alessandro Ghedini <alexbio@cpan.org>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Alessandro Ghedini.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-GitHub>
+(or L<bug-Dist-Zilla-Plugin-GitHub@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-GitHub@rt.cpan.org>).
 
 =head1 AUTHOR
 
@@ -247,7 +220,7 @@ Alessandro Ghedini <alexbio@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alessandro Ghedini Karen Etheridge Mike Friedman Jeffrey Ryan Thalhammer Dave Rolsky Doherty Rafael Kitover Brian Phillips Ricardo Signes Alexandr Ciornii Vyacheslav Matyukhin Ioan Rogers Chris Weyl
+=for stopwords Alessandro Ghedini Karen Etheridge Mike Friedman Dave Rolsky Rafael Kitover Jeffrey Ryan Thalhammer Doherty Vyacheslav Matyukhin Alexandr Ciornii Brian Phillips Chris Weyl Ioan Rogers Jose Luis Perez Diez Ricardo Signes
 
 =over 4
 
@@ -265,31 +238,19 @@ Mike Friedman <mike.friedman@10gen.com>
 
 =item *
 
-Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
-
-=item *
-
 Dave Rolsky <autarch@urth.org>
 
 =item *
 
-Mike Doherty <doherty@cs.dal.ca>
-
-=item *
-
 Rafael Kitover <rkitover@cpan.org>
 
 =item *
 
-Brian Phillips <bphillips@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
-
-=item *
-
-Alexandr Ciornii <alexchorny@gmail.com>
+Mike Doherty <doherty@cs.dal.ca>
 
 =item *
 
@@ -297,12 +258,28 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =item *
 
-Ioan Rogers <ioan.rogers@gmail.com>
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=item *
+
+Brian Phillips <bphillips@cpan.org>
 
 =item *
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=item *
+
+Ioan Rogers <ioan.rogers@gmail.com>
+
+=item *
+
+Jose Luis Perez Diez <jluis@escomposlinux.org>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
