@@ -1,8 +1,10 @@
 package Dist::Zilla::Plugin::GitHub::Meta;
-our $VERSION = '0.41';
+# ABSTRACT: Add a GitHub repo's info to META.{yml,json}
 use strict;
 use warnings;
 
+our $VERSION = '0.42';
+
 use JSON::MaybeXS;
 use Moose;
 
@@ -34,10 +36,6 @@ has fork => (
     default => 1
 );
 
-#pod =head1 NAME
-#pod
-#pod Dist::Zilla::Plugin::GitHub::Meta - Add a GitHub repo's info to META.{yml,json}
-#pod
 #pod =head1 SYNOPSIS
 #pod
 #pod Configure git with your GitHub login name:
@@ -227,20 +225,6 @@ sub metadata {
 #pod
 #pod =back
 #pod
-#pod =head1 AUTHOR
-#pod
-#pod Alessandro Ghedini <alexbio@cpan.org>
-#pod
-#pod =head1 LICENSE AND COPYRIGHT
-#pod
-#pod Copyright 2011 Alessandro Ghedini.
-#pod
-#pod This program is free software; you can redistribute it and/or modify it
-#pod under the terms of either: the GNU General Public License as published
-#pod by the Free Software Foundation; or the Artistic License.
-#pod
-#pod See http://dev.perl.org/licenses/ for more information.
-#pod
 #pod =cut
 
 no Moose;
@@ -257,11 +241,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::GitHub::Meta
+Dist::Zilla::Plugin::GitHub::Meta - Add a GitHub repo's info to META.{yml,json}
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -336,10 +320,6 @@ When offline, this is not set.
 
 =back
 
-=head1 NAME
-
-Dist::Zilla::Plugin::GitHub::Meta - Add a GitHub repo's info to META.{yml,json}
-
 =head1 ATTRIBUTES
 
 =over
@@ -381,19 +361,10 @@ one, if it's set to true (default).
 
 =back
 
-=head1 AUTHOR
+=head1 SUPPORT
 
-Alessandro Ghedini <alexbio@cpan.org>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Alessandro Ghedini.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-GitHub>
+(or L<bug-Dist-Zilla-Plugin-GitHub@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-GitHub@rt.cpan.org>).
 
 =head1 AUTHOR
 
