@@ -1,8 +1,10 @@
 package Dist::Zilla::Plugin::GitHub::Update;
-our $VERSION = '0.41';
+# ABSTRACT: Update a GitHub repo's info on release
 use strict;
 use warnings;
 
+our $VERSION = '0.42';
+
 use JSON::MaybeXS;
 use Moose;
 use List::Util 'first';
@@ -35,10 +37,6 @@ has meta_home => (
     default => 0
 );
 
-#pod =head1 NAME
-#pod
-#pod Dist::Zilla::Plugin::GitHub::Update - Update a GitHub repo's info on release
-#pod
 #pod =head1 SYNOPSIS
 #pod
 #pod Configure git with your GitHub credentials:
@@ -227,20 +225,6 @@ sub _current_params {
 #pod
 #pod =back
 #pod
-#pod =head1 AUTHOR
-#pod
-#pod Alessandro Ghedini <alexbio@cpan.org>
-#pod
-#pod =head1 LICENSE AND COPYRIGHT
-#pod
-#pod Copyright 2011 Alessandro Ghedini.
-#pod
-#pod This program is free software; you can redistribute it and/or modify it
-#pod under the terms of either: the GNU General Public License as published
-#pod by the Free Software Foundation; or the Artistic License.
-#pod
-#pod See http://dev.perl.org/licenses/ for more information.
-#pod
 #pod =cut
 
 no Moose;
@@ -257,11 +241,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::GitHub::Update
+Dist::Zilla::Plugin::GitHub::Update - Update a GitHub repo's info on release
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -294,10 +278,6 @@ See L</ATTRIBUTES> for more options.
 This Dist::Zilla plugin updates the information of the GitHub repository
 when C<dzil release> is run.
 
-=head1 NAME
-
-Dist::Zilla::Plugin::GitHub::Update - Update a GitHub repo's info on release
-
 =head1 ATTRIBUTES
 
 =over
@@ -354,19 +334,10 @@ the login, it'll be automatically enabled.
 
 =back
 
-=head1 AUTHOR
+=head1 SUPPORT
 
-Alessandro Ghedini <alexbio@cpan.org>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Alessandro Ghedini.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-GitHub>
+(or L<bug-Dist-Zilla-Plugin-GitHub@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-GitHub@rt.cpan.org>).
 
 =head1 AUTHOR
 
