@@ -1,8 +1,10 @@
 package Dist::Zilla::PluginBundle::GitHub;
-our $VERSION = '0.41';
+# ABSTRACT: GitHub plugins all-in-one
 use strict;
 use warnings;
 
+our $VERSION = '0.42';
+
 use Moose;
 
 extends 'Dist::Zilla::Plugin::GitHub';
@@ -103,10 +105,6 @@ has meta_home => (
         }
 );
 
-#pod =head1 NAME
-#pod
-#pod Dist::Zilla::PluginBundle::GitHub - GitHub plugins all-in-one
-#pod
 #pod =head1 SYNOPSIS
 #pod
 #pod Configure git with your GitHub credentials:
@@ -238,20 +236,6 @@ sub configure {
 #pod
 #pod L<Dist::Zilla::Plugin::GitHub::Meta>, L<Dist::Zilla::Plugin::GitHub::Update>
 #pod
-#pod =head1 AUTHOR
-#pod
-#pod Alessandro Ghedini <alexbio@cpan.org>
-#pod
-#pod =head1 LICENSE AND COPYRIGHT
-#pod
-#pod Copyright 2011 Alessandro Ghedini.
-#pod
-#pod This program is free software; you can redistribute it and/or modify it
-#pod under the terms of either: the GNU General Public License as published
-#pod by the Free Software Foundation; or the Artistic License.
-#pod
-#pod See http://dev.perl.org/licenses/ for more information.
-#pod
 #pod =cut
 
 no Moose;
@@ -268,11 +252,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::PluginBundle::GitHub
+Dist::Zilla::PluginBundle::GitHub - GitHub plugins all-in-one
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -298,10 +282,6 @@ then, in your F<dist.ini>:
 
 This bundle automatically adds all the GitHub plugins.
 
-=head1 NAME
-
-Dist::Zilla::PluginBundle::GitHub - GitHub plugins all-in-one
-
 =head1 ATTRIBUTES
 
 =over
@@ -384,19 +364,10 @@ Prompt for GitHub two-factor authentication code if this option is set to true
 
 L<Dist::Zilla::Plugin::GitHub::Meta>, L<Dist::Zilla::Plugin::GitHub::Update>
 
-=head1 AUTHOR
+=head1 SUPPORT
 
-Alessandro Ghedini <alexbio@cpan.org>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Alessandro Ghedini.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-GitHub>
+(or L<bug-Dist-Zilla-Plugin-GitHub@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-GitHub@rt.cpan.org>).
 
 =head1 AUTHOR
 
